/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.mock;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;

import org.loom.servlet.params.FileParameter;

public class MockFileParameter implements FileParameter {

	private InputStream is;
	
	private String contents = "foo bar";
	
	private String filename;
	
	public MockFileParameter(String filename) {
		this.filename = filename;
	}

	public MockFileParameter(String filename, InputStream is) {
		this.filename = filename;
		if (is == null) {
			throw new IllegalArgumentException("Resource " + filename + " could not be found");
		}
		this.is = is;
	}

	public String getContentType() {
		return "text/html";
	}

	public long getFileSize() {
		return contents.length();
	}

	public String getFilename() {
		return filename;
	}

	public byte[] getBytes() {
		return contents.getBytes();
	}

	public InputStream getStream() throws IOException {
		return is == null? new ByteArrayInputStream(contents.getBytes()) : is;
	}

	public void setStream(InputStream is) throws IOException {
		this.is = is;
	}

	public String getString() {
		return null;
	}

	public void setContentType(String contentType) {
	}

	public void setFilename(String filename) {
		this.filename = filename;
	}

}
